2016-03-08 12:57:22 -06:00
|
|
|
/*
|
|
|
|
|
Copyright (c) 2015-2016 Advanced Micro Devices, Inc. All rights reserved.
|
|
|
|
|
Permission is hereby granted, free of charge, to any person obtaining a copy
|
|
|
|
|
of this software and associated documentation files (the "Software"), to deal
|
|
|
|
|
in the Software without restriction, including without limitation the rights
|
|
|
|
|
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
|
|
|
|
copies of the Software, and to permit persons to whom the Software is
|
|
|
|
|
furnished to do so, subject to the following conditions:
|
|
|
|
|
The above copyright notice and this permission notice shall be included in
|
|
|
|
|
all copies or substantial portions of the Software.
|
|
|
|
|
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
|
|
|
|
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
|
|
|
|
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
|
|
|
|
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
|
|
|
|
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
|
|
|
|
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
|
|
|
|
THE SOFTWARE.
|
|
|
|
|
*/
|
|
|
|
|
|
2016-03-07 03:42:50 -06:00
|
|
|
#include"test_common.h"
|
2016-03-08 12:57:22 -06:00
|
|
|
#include<malloc.h>
|
2016-03-07 03:42:50 -06:00
|
|
|
|
|
|
|
|
__global__ void Inc(hipLaunchParm lp, float *Ad){
|
|
|
|
|
int tx = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
|
|
|
|
|
Ad[tx] = Ad[tx] + float(1);
|
|
|
|
|
}
|
|
|
|
|
|
|
|
|
|
int main(){
|
|
|
|
|
float *A, *Ad;
|
|
|
|
|
const size_t size = N * sizeof(float);
|
2016-03-08 12:57:22 -06:00
|
|
|
A = (float*)malloc(size*2);
|
2016-04-11 10:28:16 -05:00
|
|
|
|
2016-03-07 03:42:50 -06:00
|
|
|
HIPCHECK(hipHostRegister(A, size, 0));
|
|
|
|
|
|
|
|
|
|
for(int i=0;i<N;i++){
|
|
|
|
|
A[i] = float(1);
|
|
|
|
|
}
|
|
|
|
|
|
|
|
|
|
HIPCHECK(hipMalloc(&Ad, size));
|
2016-04-11 10:28:16 -05:00
|
|
|
hipStream_t stream;
|
|
|
|
|
HIPCHECK(hipStreamCreate(&stream));
|
|
|
|
|
|
|
|
|
|
HIPCHECK(hipMemcpyAsync(Ad, A, size, hipMemcpyHostToDevice, stream));
|
|
|
|
|
|
|
|
|
|
hipLaunchKernel(HIP_KERNEL_NAME(Inc), dim3(N/512), dim3(512), 0, stream, Ad);
|
|
|
|
|
HIPCHECK(hipDeviceSynchronize());
|
|
|
|
|
|
|
|
|
|
HIPCHECK(hipMemcpyAsync(A, Ad, size, hipMemcpyDeviceToHost, stream));
|
|
|
|
|
|
|
|
|
|
HIPASSERT(A[10] == 2.0f);
|
2016-03-07 03:42:50 -06:00
|
|
|
|
|
|
|
|
HIPCHECK(hipMemcpy(Ad, A, size, hipMemcpyHostToDevice));
|
|
|
|
|
|
|
|
|
|
hipLaunchKernel(HIP_KERNEL_NAME(Inc), dim3(N/512), dim3(512), 0, 0, Ad);
|
|
|
|
|
HIPCHECK(hipDeviceSynchronize());
|
|
|
|
|
|
|
|
|
|
HIPCHECK(hipMemcpy(A, Ad, size, hipMemcpyDeviceToHost));
|
|
|
|
|
|
2016-04-11 10:28:16 -05:00
|
|
|
HIPASSERT(A[10] == 3.0f);
|
|
|
|
|
|
|
|
|
|
|
2016-03-07 03:42:50 -06:00
|
|
|
HIPCHECK(hipHostUnregister(A));
|
2016-04-11 10:28:16 -05:00
|
|
|
HIPCHECK(hipStreamDestroy(stream));
|
2016-03-07 03:42:50 -06:00
|
|
|
passed();
|
|
|
|
|
}
|